
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '38.5.2',
    'branch_nick': 'release-38-LTS',
    'revision_id': 'bc8c312662c64d1bb25c1774d8689fd860136471',
    'revno': 14131
}
